@@ -18,7 +18,7 @@ G_BEGIN_DECLS
 #undef GDK_WINDOWING_MACOS
 
 #ifndef GENTOO_GTK_HIDE_WAYLAND
-#define GDK_WINDOWING_WAYLAND
+#undef GDK_WINDOWING_WAYLAND
 #endif
 
 #undef GDK_WINDOWING_WIN32
